seqtools.partition_sequence_extended_to_counts_without_overhang
===============================================================

.. autofunction:: abjad.tools.seqtools.partition_sequence_extended_to_counts_without_overhang
